// part of the python bindings
#ifdef NO_PYTHON_LIB
#include "Python.h"
  #include <boost/python.hpp>
  #include <boost/format.hpp>
  #include "Types.h"
  #include "Colour.h"
  #include "Vector.h"
  #include "Matrix.h"
  #include "Quaternion.h"
  #include "BBox.h"
  #include "Camera.h"
  #include "VBOPrimitives.h"
  #include "Light.h"
  #include "Material.h"
  #include "AbstractMesh.h"
  #include "Obj.h"
  #include "ShaderManager.h"
  #include "Transformation.h"
  #include "TransformStack.h"
  #include "Texture.h"
  #include "BezierCurve.h"
  #include "PathCamera.h"
  #include "HoudiniGeo.h"
  #include "Clip.h"
  #include "NCCABinMesh.h"
  #include "SpotLight.h"
  #include "Random.h"
  #include "NCCAPointBake.h"
  #include "NGLInit.h"
  #include "Shader.h"
  #include "ShaderProgram.h"
	#include "Plane.h"
#endif
/// @file PythonWrapper.cpp
/// @brief this is the python wrapper for the ngl library
/// this is quite convoluted as we need to have access to the methods etc
/// as well as wrapping other stuff into the BOOST_PYTHON_MODULE element
/// where we must have all the classes defined in the same module
/// So to break it all down we have .inc.cpp files with the access and
/// methods needed for the library access
/// in the .inc.h files is the boost::python class wrappers
/// the inc.cpp elements must be bundled in the namespace ngl{
/// the .inc.h elements are just the python code as the MODULE element
/// is already wrapped in the namespace
#include "Colour.inc.cpp"
#include "Vector.inc.cpp"
#include "Matrix.inc.cpp"
#include "Quaternion.inc.cpp"
#include "Material.inc.cpp"
#include "Transformation.inc.cpp"
#include "TransformStack.inc.cpp"
#include "BezierCurve.inc.cpp"
#include "Clip.inc.cpp"
#include "Random.inc.cpp"
#include "ShaderManager.inc.cpp"
#include "AbstractMesh.inc.cpp"


namespace ngl
{
  // create a python module
  BOOST_PYTHON_MODULE(PyNGL)
  {
    #include "../python/Colour.inc.h"
    #include "../python/Vector.inc.h"
    #include "../python/Matrix.inc.h"
    #include "../python/Quaternion.inc.h"
    #include "../python/BBox.inc.h"
    #include "../python/Camera.inc.h"
    #include "../python/VBOPrimitives.inc.h"
    #include "../python/Light.inc.h"
    #include "../python/Material.inc.h"
    #include "../python/AbstractMesh.inc.h"
    #include "../python/Obj.inc.h"
    #include "../python/ShaderManager.inc.h"
    #include "../python/Transformation.inc.h"
    #include "../python/TransformStack.inc.h"
    #include "../python/Texture.inc.h"
    #include "../python/BezierCurve.inc.h"
    #include "../python/PathCamera.inc.h"
    #include "../python/HoudiniGeo.inc.h"
    #include "../python/Clip.inc.h"
    #include "../python/NCCABinMesh.inc.h"
    #include "../python/SpotLight.inc.h"
    #include "../python/Random.inc.h"
    #include "../python/NCCAPointBake.inc.h"
    #include "../python/NGLInit.inc.h"
    #include "../python/Shader.inc.h"
    #include "../python/ShaderProgram.inc.h"
		#include "../python/Plane.inc.h"

  };

} // end ngl namespace
