/*
  Copyright (C) 2009 Jon Macey

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#include "Types.h"
#ifdef __USINGWINDOWS__
  #include <windows.h>
#endif
#ifdef LINUX
  #include <GL/gl.h>
  #include <cstdlib>
#endif
#ifdef DARWIN
  #include <unistd.h>
  #include <OpenGL/gl.h>
#endif
#include "Vector.h"
#include <QDebug>
//----------------------------------------------------------------------------------------------------------------------
/// @file Util.cpp
/// @brief implementation files for Util class
//----------------------------------------------------------------------------------------------------------------------
namespace ngl
{

//----------------------------------------------------------------------------------------------------------------------
NGL_DLLEXPORT Vector  calcNormal (
                                 const ngl::Vector &_p1,
                                 const ngl::Vector &_p2,
                                 const ngl::Vector &_p3
                                )
{

	ngl::Real coa, cob, coc ;
	ngl::Real px1, py1, pz1 ;
	ngl::Real px2, py2, pz2 ;
	ngl::Real px3, py3, pz3 ;
	ngl::Real absvec;
	ngl::Vector norm;
	px1 = _p1.m_x; py1 = _p1.m_y; pz1 = _p1.m_z;
	px2 = _p2.m_x; py2 = _p2.m_y; pz2 = _p2.m_z;
	px3 = _p3.m_x; py3 = _p3.m_y; pz3 = _p3.m_z;

	// generate cross product

	coa = -(py1 * (pz2-pz3) + py2*(pz3-pz1) + py3*(pz1-pz2)) ;
	cob = -(pz1 * (px2-px3) + pz2*(px3-px1) + pz3*(px1-px2)) ;
	coc = -(px1 * (py2-py3) + px2*(py3-py1) + px3*(py1-py2)) ;

	// normalise the results to get unit length normal
  absvec = sqrtf ( ((coa*coa) + (cob*cob) + (coc*coc))) ;
	norm.m_x = coa/absvec ;
	norm.m_y = cob/absvec ;
	norm.m_z = coc/absvec ;
	norm.m_w=0.0f;

	return norm;
}



NGL_DLLEXPORT Real radians(
                            const ngl::Real _deg
                            )
{
	return (_deg/180.0f) * M_PI;
}

//----------------------------------------------------------------------------------------------------------------------
NGL_DLLEXPORT Real degrees(
                            const Real _rad
                           )
{
	return (_rad / M_PI) * 180.0f;
}


NGL_DLLEXPORT  void NGLCheckGLError(
                                      const std::string  &_file,
                                      const int _line
                                    )
{
 int err_num = glGetError();

	while (err_num != GL_NO_ERROR)
  {
    const char* str = (const char*)gluErrorString(err_num);
    QString message =QString("GL: %1  line: %2, file: %3").arg( str).arg( _line).arg( _file.c_str());
    qDebug()<<message;
    err_num = glGetError();

  }
}


} // end of namespace

//----------------------------------------------------------------------------------------------------------------------



