/*
  Copyright (C) 2009 Jon Macey

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#include "VertexArrayObject.h"
#include <iostream>
//----------------------------------------------------------------------------------------------------------------------
/// @file VertexArrayObject.cpp
/// @brief implementation files for VertexArrayObject class
//----------------------------------------------------------------------------------------------------------------------
namespace ngl
{

//----------------------------------------------------------------------------------------------------------------------
VertexArrayObject::VertexArrayObject(
																			 GLenum _mode
																		 )
{
	m_allocated=false;
	// first we create a vertex array Object
  glGenVertexArrays(1, &m_id);
	m_bound=false;
	m_drawMode=_mode;
	m_indicesCount=0;
}

//----------------------------------------------------------------------------------------------------------------------
void VertexArrayObject::bind()
{
	glBindVertexArray(m_id);
	m_bound=true;
}
//----------------------------------------------------------------------------------------------------------------------
void VertexArrayObject::unbind()
{
	glBindVertexArray(0);
	glEnableVertexAttribArray(0);

	m_bound=false;
}
//----------------------------------------------------------------------------------------------------------------------
void VertexArrayObject::removeVOA()
{
	if(m_bound == true)
	{
		unbind();
	}
	if( m_allocated ==true)
	{
	glDeleteVertexArrays(1,&m_id);
	m_allocated=false;
	}
}
//----------------------------------------------------------------------------------------------------------------------
void VertexArrayObject::setData(
																 unsigned int _size,
                                const GLfloat &_data,
																 GLenum _mode
																)
{
	if(m_bound == false)
	{
		std::cerr<<"trying to set VOA data when unbound\n";
	}
	GLuint vboID;
	glGenBuffers(1, &vboID);
	// now we will bind an array buffer to the first one and load the data for the verts
	glBindBuffer(GL_ARRAY_BUFFER, vboID);
	glBufferData(GL_ARRAY_BUFFER, _size, &_data, _mode);
	m_allocated=true;

}

//----------------------------------------------------------------------------------------------------------------------
void VertexArrayObject::setVertexAttributePointer(
																										GLuint _id,
																										GLint _size,
																										GLenum _type,
																										GLsizei _stride,
																										unsigned int _dataOffset,
																										bool _normalise
																									)
{
	if(m_bound !=true)
	{
		std::cerr<<"Warning trying to set attribute on Unbound VOA\n";
	}

	glVertexAttribPointer(_id,_size,_type,_normalise,_stride,((float *)NULL + (_dataOffset)));
	glEnableVertexAttribArray(_id);
}
//----------------------------------------------------------------------------------------------------------------------
void VertexArrayObject::draw() const
{
	if(m_allocated == false)
	{
		std::cerr<<"Warning trying to draw an unallocated VOA\n";
	}
	if(m_bound == false)
	{
		std::cerr<<"Warning trying to draw an unbound VOA\n";
	}

	glDrawArrays(m_drawMode, 0, m_indicesCount);	// draw first object


}
//----------------------------------------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------------------------------------

} // end namspace ngl



